@@ -15,7 +15,7 @@
 #include "config.h"
 #endif
 
-#include "xsltconfig.h"
+#include <libxslt/xsltconfig.h>
 #include <libxml/xmlversion.h>
 
 #if !defined LIBEXSLT_PUBLIC
